@@ -1,5 +1,5 @@
 /*###################################################################*/
-/*##                         clock & mail applet 0.1.2 alpha       ##*/
+/*##                         clock & mail applet 0.1.4             ##*/
 /*###################################################################*/
 
 #include "clockmail.h"
@@ -18,7 +18,11 @@ int ALWAYS_BLINK = FALSE;
 /* mail file location */
 char *mail_file = NULL;
 
-static GtkWidget *applet;
+/* execute a command on new mail */
+char *newmail_exec_cmd = NULL;
+int EXEC_CMD_ON_NEWMAIL = FALSE;
+
+GtkWidget *applet;
 static GtkWidget *frame;
 static GtkWidget *display_area;
 static GtkTooltips *tooltips;
@@ -39,7 +43,7 @@ static int blink_count = 0;
 static void about_cb (AppletWidget *widget, gpointer data)
 {
 	GtkWidget *about;
-	gchar *authors[2];
+	const gchar *authors[2];
 	gchar version[32];
 
 	sprintf(version,_("%d.%d.%d"),CLOCKMAIL_APPLET_VERSION_MAJ,
@@ -98,7 +102,7 @@ void check_mail_file_status (int reset)
 	anymail = newsize > 0;
 	unreadmail = (s.st_mtime >= s.st_atime && newsize > 0);
 
-	checktime = (ALWAYS_BLINK || newtime > oldtime);
+	checktime = (newtime > oldtime);
 	if (newsize >= oldsize && unreadmail && checktime){
 		newmail = 1;
 		mailcleared = 0;
@@ -248,11 +252,16 @@ static gint update_display()
 	if (!blinking)
 		{
 		if (anymail)
-			if (newmail)
+			if (newmail || ALWAYS_BLINK)
 				{
 				update_mail_display(1);
 				blinking = TRUE;
 				blink_timeout_id = gtk_timeout_add( BLINK_DELAY , (GtkFunction)blink_callback, NULL);
+				if (newmail && EXEC_CMD_ON_NEWMAIL)
+					{
+					if (newmail_exec_cmd && strlen(newmail_exec_cmd) > 0)
+						gnome_execute_shell(NULL, newmail_exec_cmd);
+					}
 				}
 			else
 				{
@@ -291,9 +300,9 @@ static void applet_change_orient(GtkWidget *w, PanelOrientType o, gpointer data)
 	/* orient change (nothing is done in this applet */
 }
 
-static gint applet_session_save(GtkWidget *widget, char *cfgpath, char *globcfgpath)
+static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath)
 {
-        property_save(cfgpath);
+        property_save(privcfgpath);
         return FALSE;
 }
 
@@ -310,7 +319,7 @@ int main (int argc, char *argv[])
 	if (!applet)
 		g_error("Can't create applet!\n");
 
-	property_load(APPLET_WIDGET(applet)->cfgpath);
+	property_load(APPLET_WIDGET(applet)->privcfgpath);
 
 	/* get mail filename from environment if not specified in the session file */
 	if (!strcmp(mail_file,"default"))
@@ -351,16 +360,22 @@ int main (int argc, char *argv[])
 
 	gtk_widget_show(applet);
 
-	gtk_signal_connect(GTK_OBJECT(applet),"session_save",
-		GTK_SIGNAL_FUNC(applet_session_save), NULL);
+	gtk_signal_connect(GTK_OBJECT(applet),"save_session",
+		GTK_SIGNAL_FUNC(applet_save_session), NULL);
 
-	applet_widget_register_callback(APPLET_WIDGET(applet),
-					     "properties",
-					     _("Properties..."),
-					     property_show,
-					     NULL);
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+						"properties",
+						GNOME_STOCK_MENU_PROP,
+						_("Properties..."),
+						property_show,
+						NULL);
 
-	applet_widget_register_callback(APPLET_WIDGET(applet), "about", _("About..."), about_cb, NULL);
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+						"about",
+						GNOME_STOCK_MENU_ABOUT,
+						_("About..."),
+						about_cb,
+						NULL);
 
 	gdk_draw_pixmap     (display,display_area->style->fg_gc[GTK_WIDGET_STATE(display_area)],
 		display_back, 0, 0, 0, 0, 46, 42);
