@@ -22,6 +22,9 @@ char **env;
 #define DEFAULT_FONT "-misc-fixed-medium-r-normal--20-200-75-75-c-100-iso8859-1"
 #define EXTRA 2
 
+/* Name of section to discard if --discard given.  */
+static char *discard_section = NULL;
+
 /* Font used by the terminals */
 char *font = NULL;
 
@@ -58,6 +61,10 @@ int blink;
 /* Initial command */
 char **initial_command = NULL;
 
+/* This is the terminal associated with the initial command, or NULL
+   if there isn't one.  */
+GtkWidget *initial_term = NULL;
+
 /* A list of all the open terminals */
 GList *terminals = 0;
 
@@ -67,6 +74,9 @@ GdkColor user_fore, user_back;
 /* The colors specified on the command line */
 char *fore_color = NULL, *back_color = NULL;
 
+/* Whether to show the menubar */
+int menubar_hidden = 0;
+
 typedef struct {
 	GtkWidget *prop_win;
 	GtkWidget *blink_checkbox;
@@ -74,6 +84,7 @@ typedef struct {
 	GtkWidget *color_scheme;
 	GtkWidget *def_fore_back;
 	GtkWidget *scrollbar;
+	GtkWidget *scrollback_spin;
 	GnomeColorSelector *fore_cs;
 	GnomeColorSelector *back_cs;
 } preferences_t;
@@ -103,12 +114,15 @@ static void
 close_app (GtkWidget *app) {
         terminals = g_list_remove(terminals, app);
 
+	if (app == initial_term)
+		initial_term = NULL;
+
 	gtk_widget_destroy(app);
 
 	if(terminals == NULL)
 	       gtk_main_quit();
 }
-    
+
 
 static void
 close_terminal_cmd (void *unused, void *data)
@@ -116,6 +130,8 @@ close_terminal_cmd (void *unused, void *data)
 	GtkWidget *top = gtk_widget_get_toplevel (GTK_WIDGET (data));
 
 	terminals = g_list_remove (terminals, top);
+	if (top == initial_term)
+		initial_term = NULL;
 	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (data)));
 	if (terminals == NULL)
 		gtk_main_quit ();
@@ -276,37 +292,41 @@ apply_changes (GtkWidget *widget, int page, ZvtTerm *term)
 	GtkWidget *scrollbar = gtk_object_get_data (GTK_OBJECT (term), "scrollbar");
 	GtkWidget *box       = scrollbar->parent;
 
-	if (page != -1)
-		return;
-	
-	zvt_term_set_font_name (term, gtk_entry_get_text (GTK_ENTRY (prefs->font_entry)));
-	zvt_term_set_blink (term, GTK_TOGGLE_BUTTON (prefs->blink_checkbox)->active);
-	color_type = (int) gtk_object_get_user_data (GTK_OBJECT (prefs->color_scheme));
-	scrollpos  = (int) gtk_object_get_user_data (GTK_OBJECT (prefs->scrollbar));
-	color_set  = (int) gtk_object_get_user_data (GTK_OBJECT (prefs->def_fore_back));
-	gnome_color_selector_get_color_int (prefs->fore_cs, &r, &g, &b, 65535);
-	user_fore.red   = r;
-	user_fore.green = g;
-	user_fore.blue  = b;
-	gnome_color_selector_get_color_int (prefs->back_cs, &r, &g, &b, 65535);
-	user_back.red   = r;
-	user_back.green = g;
-	user_back.blue  = b;
-	
-	/* sve the global variables */
-	blink = GTK_TOGGLE_BUTTON (prefs->blink_checkbox)->active;
-	if (font)
-		g_free (font);
-	font  = g_strdup (gtk_entry_get_text (GTK_ENTRY (prefs->font_entry)));
-	scrollbar_position = scrollpos;
-
-	set_color_scheme (term, color_type);
-	if (scrollpos == SCROLLBAR_HIDDEN)
-		gtk_widget_hide (scrollbar);
-	else {
-		gtk_box_reorder_child (GTK_BOX (box), scrollbar,
-				       scrollpos == SCROLLBAR_LEFT ? 0 : 1);
-		gtk_widget_show (scrollbar);
+	/* get page details separately */
+	switch(page) {
+	case 0:
+		zvt_term_set_font_name (term, gtk_entry_get_text (GTK_ENTRY (prefs->font_entry)));
+		zvt_term_set_blink (term, GTK_TOGGLE_BUTTON (prefs->blink_checkbox)->active);
+		scrollpos  = (int) gtk_object_get_user_data (GTK_OBJECT (prefs->scrollbar));
+		blink = GTK_TOGGLE_BUTTON (prefs->blink_checkbox)->active;
+		scrollback = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (prefs->scrollback_spin)); 
+		zvt_term_set_scrollback (term, scrollback);
+		if (font)
+			g_free (font);
+		font  = g_strdup (gtk_entry_get_text (GTK_ENTRY (prefs->font_entry)));
+		scrollbar_position = scrollpos;
+		if (scrollpos == SCROLLBAR_HIDDEN)
+			gtk_widget_hide (scrollbar);
+		else {
+			gtk_box_reorder_child (GTK_BOX (box), scrollbar,
+					       scrollpos == SCROLLBAR_LEFT ? 0 : 1);
+			gtk_widget_show (scrollbar);
+		}
+		break;
+	case 1:
+		color_type = (int) gtk_object_get_user_data (GTK_OBJECT (prefs->color_scheme));
+		color_set  = (int) gtk_object_get_user_data (GTK_OBJECT (prefs->def_fore_back));
+		gnome_color_selector_get_color_int (prefs->fore_cs, &r, &g, &b, 65535);
+		user_fore.red   = r;
+		user_fore.green = g;
+		user_fore.blue  = b;
+		gnome_color_selector_get_color_int (prefs->back_cs, &r, &g, &b, 65535);
+		user_back.red   = r;
+		user_back.green = g;
+		user_back.blue  = b;
+		
+		set_color_scheme (term, color_type);
+		break;
 	}
 }
 
@@ -445,8 +465,9 @@ enum {
 	FORECOLOR_ROW = 3,
 	BACKCOLOR_ROW = 4,
 	SCROLL_ROW    = 1,
-	FONT_ROW      = 2,
-	BLINK_ROW     = 3
+	SCROLLBACK_ROW = 2,
+	FONT_ROW      = 3,
+	BLINK_ROW     = 4
 };
 
 /* called back to free the ColorSelector */
@@ -461,6 +482,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	GtkWidget *l, *table, *o, *m, *b1, *b2;
 	preferences_t *prefs;
+	GtkAdjustment *adj;
 
 	/* Is a property window for this terminal already running? */
 	prefs = gtk_object_get_data (GTK_OBJECT (term), "prefs");
@@ -472,7 +494,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_object_set_data (GTK_OBJECT (term), "prefs", prefs);
 
 	/* Look page */
-	table = gtk_table_new (0, 0, 0);
+	table = gtk_table_new (3, 4, FALSE);
 	gnome_property_box_append_page (GNOME_PROPERTY_BOX (prefs->prop_win),
 					table, gtk_label_new (_("Look")));
 
@@ -513,8 +535,17 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_table_attach (GTK_TABLE (table), prefs->blink_checkbox,
 			  2, 3, BLINK_ROW, BLINK_ROW+1, GTK_FILL, 0, GNOME_PAD, GNOME_PAD);
 
+	/* Scroll back */
+	l = aligned_label (_("Scrollback lines"));
+        gtk_table_attach (GTK_TABLE (table), l, 1, 2, SCROLLBACK_ROW, SCROLLBACK_ROW+1, GTK_FILL, 0, GNOME_PAD, GNOME_PAD);
+	adj = (GtkAdjustment *) gtk_adjustment_new ((gfloat)scrollback, 1.0, 1000.0, 1.0, 5.0, 0.0);
+	prefs->scrollback_spin = gtk_spin_button_new (adj, 0, 0);
+	gtk_signal_connect (GTK_OBJECT (prefs->scrollback_spin), "changed",
+			    GTK_SIGNAL_FUNC (prop_changed), prefs);
+	gtk_table_attach (GTK_TABLE (table), prefs->scrollback_spin,
+			  2, 3, SCROLLBACK_ROW, SCROLLBACK_ROW+1, GTK_FILL, 0, GNOME_PAD, GNOME_PAD);
 	/* Color page */
-	table = gtk_table_new (0, 0, 0);
+	table = gtk_table_new (4, 4, FALSE);
 	gnome_property_box_append_page (GNOME_PROPERTY_BOX (prefs->prop_win), table, gtk_label_new (_("Colors")));
 	
 	/* Color palette */
@@ -613,15 +644,26 @@ save_preferences (GtkWidget *widget, ZvtTerm *term)
 				 color_type == 0 ? "linux" : (color_type == 1 ? "xterm" : "rxvt"));
 	gnome_config_set_string ("/Terminal/Config/foreground", get_color_string (user_fore));
 	gnome_config_set_string ("/Terminal/Config/background", get_color_string (user_back));
-	
+	gnome_config_set_bool   ("/Terminal/Config/menubar", !menubar_hidden);
 	gnome_config_sync ();
 }
 
+static void
+hide_cmd (GtkWidget *widget, ZvtTerm *term)
+{
+	GnomeApp *app = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
+
+	menubar_hidden = 1;
+	gtk_widget_hide (app->menubar);
+	save_preferences (widget, term);
+}
+
 static GnomeUIInfo gnome_terminal_terminal_menu [] = {
 	{ GNOME_APP_UI_ITEM, N_("New terminal"),    NULL, new_terminal },
 	{ GNOME_APP_UI_ITEM, N_("Save preferences"),NULL, save_preferences },
 	{ GNOME_APP_UI_ITEM, N_("Close terminal"),  NULL, close_terminal_cmd },
 	{ GNOME_APP_UI_SEPARATOR },
+	{ GNOME_APP_UI_ITEM, N_("Hide menubar..."), NULL, hide_cmd },
 	{ GNOME_APP_UI_ITEM, N_("Properties..."),   NULL, preferences_cmd, 0, 0,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP },
 	{ GNOME_APP_UI_ITEM, N_("Color selector..."),   NULL, color_cmd },
@@ -757,6 +799,21 @@ configure_term_dnd (ZvtTerm *term)
 			    GTK_SIGNAL_FUNC (drop_data_available), term);
 }
 
+static int
+button_press (GtkWidget *widget, GdkEventButton *event, ZvtTerm *term)
+{
+	GnomeApp *app = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (term)));
+
+	/* FIXME: this should popup a menu instead */
+	if (event->state & GDK_CONTROL_MASK){
+		menubar_hidden = 0;
+		gtk_widget_show (app->menubar);
+		save_preferences (widget, term);
+		return 1;
+	}
+	return 0;
+}
+
 void
 new_terminal_cmd (char **cmd)
 {
@@ -801,6 +858,9 @@ new_terminal_cmd (char **cmd)
 	app = gnome_app_new ("Terminal", "Terminal");
 	gtk_window_set_wmclass (GTK_WINDOW (app), "GnomeTerminal", "GnomeTerminal");
 
+	if (cmd != NULL)
+		initial_term = app;
+
 #ifdef ZVT_USES_MINIMAL_ALLOC
 	gtk_window_set_policy  (GTK_WINDOW (app), 1, 1, 1);
 #else
@@ -826,7 +886,12 @@ new_terminal_cmd (char **cmd)
 	gtk_signal_connect(GTK_OBJECT(app), "delete_event",
 			   GTK_SIGNAL_FUNC(close_app), term);
 
+	gtk_signal_connect (GTK_OBJECT (term), "button_press_event",
+			    GTK_SIGNAL_FUNC (button_press), term);
+	
 	gnome_app_create_menus_with_data (GNOME_APP (app), gnome_terminal_menu, term);
+	if (menubar_hidden)
+		gtk_widget_hide (GNOME_APP (app)->menubar);
 	
 	/* Decorations */
 	hbox = gtk_hbox_new (0, 0);
@@ -934,6 +999,8 @@ terminal_load_defaults (void)
 	} else
 		color_set = COLORS_CUSTOM;
 
+	menubar_hidden = !gnome_config_get_bool ("/Terminal/Config/menubar=true");
+	
 	/* Custom colors: load them */
 	if (color_set == COLORS_CUSTOM){
 		if (strcasecmp (fore_color, back_color) == 0)
@@ -946,6 +1013,119 @@ terminal_load_defaults (void)
 	}
 }
 
+static gboolean
+load_session (GnomeClient *client)
+{
+	int num_terms, i;
+	gboolean def;
+
+	gnome_config_push_prefix (gnome_client_get_config_prefix (client));
+
+	num_terms = gnome_config_get_int_with_default ("dummy/num_terms", &def);
+	if (def || ! num_terms)
+		return FALSE;
+
+	for (i = 0; i < num_terms; ++i) {
+		char buffer[50], *geom, **argv;
+		int argc;
+
+		sprintf (buffer, "%d/geometry", i);
+		geom = gnome_config_get_string (buffer);
+
+		sprintf (buffer, "%d/command", i);
+		gnome_config_get_vector (buffer, &argc, &argv);
+
+		geometry = geom;
+		new_terminal_cmd (argv);
+
+		g_free (geom);
+		gnome_string_array_free (argv);
+	}
+
+	return TRUE;
+}
+
+/* Save terminal in this session.  FIXME: should save all terminal
+   windows, but currently does not.  */
+static gint
+save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
+	      gint is_shutdown, GnomeInteractStyle interact_style,
+	      gint is_fast, gpointer client_data)
+{
+	if (gnome_client_get_id (client)) {
+		char *section = gnome_client_get_config_prefix (client);
+		char *args[11];
+		int argc = 0, d1, d2, i;
+		GList *list;
+
+		gnome_config_clean_file (section);
+		gnome_config_push_prefix (section);
+
+		i = 0;
+		for (list = terminals; list != NULL; list = list->next) {
+			/* FIXME: we really ought to be able to set
+			   the font and other information on a
+			   per-terminal basis.  But that means a lot
+			   of rewriting of this whole file, which I
+			   don't feel like doing right now.  Global
+			   variables are evil.  */
+			char buffer[50], *geom;
+			GtkWidget *top = gtk_widget_get_toplevel (GTK_WIDGET (list->data));
+
+			sprintf (buffer, "%d/geometry", i);
+			geom = gnome_geometry_string (top->window);
+			gnome_config_set_string (buffer, geom);
+			g_free (geom);
+
+			if (top == initial_term) {
+				int n;
+				for (n = 0; initial_command[n]; ++n)
+					;
+				sprintf (buffer, "%d/command", i);
+				gnome_config_set_vector (buffer, n,
+							 initial_command);
+			}
+
+			++i;
+		}
+		gnome_config_set_int ("dummy/num_terms", i);
+
+		gnome_config_pop_prefix ();
+		gnome_config_sync ();
+
+		args[argc++] = (char *) client_data;
+		args[argc++] = "--font";
+		args[argc++] = font;
+		args[argc++] = invoke_as_login_shell ? "--login" : "--nologin";
+		args[argc++] = "--foreground";
+		args[d1 = argc++] = g_strdup (get_color_string (user_fore));
+		args[argc++] = "--background";
+		args[d2 = argc++] = g_strdup (get_color_string (user_back));
+
+		args[argc] = NULL;
+
+		gnome_client_set_restart_command (client, argc, args);
+
+		g_free (args[d1]);
+		g_free (args[d2]);
+
+		args[1] = "--discard";
+		args[2] = section;
+		args[3] = NULL;
+
+		gnome_client_set_discard_command (client, 3, args);
+	}
+
+	return TRUE;
+}
+
+static gint
+die (GnomeClient *client, gpointer client_data)
+{
+	close_all_cmd ();
+	return TRUE;
+}
+
 /* Keys for the ARGP parser, should be negative */
 enum {
 	FONT_KEY     = -1,
@@ -954,7 +1134,8 @@ enum {
 	GEOMETRY_KEY = -4,
 	COMMAND_KEY  = -5,
 	FORE_KEY     = -6,
-	BACK_KEY     = -7
+	BACK_KEY     = -7,
+	DISCARD_KEY  = -8
 };
 
 static struct argp_option argp_options [] = {
@@ -965,6 +1146,7 @@ static struct argp_option argp_options [] = {
 	{ "command",    COMMAND_KEY,  N_("COMMAND"),0,N_("Execute this program instead of a shell"), 0 },
 	{ "foreground", FORE_KEY,     N_("COLOR"),0, N_("Foreground color"), 0 },
 	{ "background", BACK_KEY,     N_("COLOR"),0, N_("Background color"), 0 },
+	{ "discard",    DISCARD_KEY,  N_("ID"),   OPTION_HIDDEN, NULL, 0 },
 	{ NULL, 0, NULL, 0, NULL, 0 },
 };
 
@@ -996,6 +1178,10 @@ parse_an_arg (int key, char *arg, struct argp_state *state)
 		back_color = arg;
 		color_set  = COLORS_CUSTOM;
 		break;
+	case DISCARD_KEY:
+		gnome_client_disable_master_connection ();
+		discard_section = arg;
+		break;
 	default:
 		return ARGP_ERR_UNKNOWN;
 	}
@@ -1010,6 +1196,8 @@ static struct argp parser =
 int
 main (int argc, char *argv [], char **environ)
 {
+	GnomeClient *client, *clone;
+
 	argp_program_version = VERSION;
 
 	env = environ;
@@ -1019,10 +1207,23 @@ main (int argc, char *argv [], char **environ)
 	
 	gnome_init ("Terminal", &parser, argc, argv, 0, NULL);
 
+	if (discard_section) {
+		gnome_config_clean_file (discard_section);
+		return 0;
+	}
+
+	client = gnome_master_client ();
+	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
+			    GTK_SIGNAL_FUNC (save_session), argv[0]);
+	gtk_signal_connect (GTK_OBJECT (client), "die",
+			    GTK_SIGNAL_FUNC (die), NULL);
+
 	terminal_load_defaults ();
 
-	new_terminal_cmd (initial_command);
-	
+	clone = gnome_cloned_client ();
+	if (! clone || ! load_session (clone))
+		new_terminal_cmd (initial_command);
+
 	gtk_main ();
 	return 0;
 }
