@@ -18,6 +18,10 @@
    02111-1307, USA.  */
 
 #include <string.h>
+#include <stdlib.h>
+
+#include <libgnome/libgnome.h>
+#include <gtk/gtk.h>
 
 #include "manager.h"
 
@@ -236,12 +240,28 @@ save_yourself_request (SmsConn connection, SmPointer data, int save_type,
 		       Bool shutdown, int interact_style, Bool fast,
 		       Bool global)
 {
+  Client *client = (Client *) data;
+
   if (saving)
-    return;
+    {
+      /* FIXME: should queue the save for later.  */
+      return;
+    }
 
   if (! global)
     {
-      /* FIXME ... */
+      /* Discard single saves requested for a non-live client.  */
+      if (! g_slist_find (live_list, client))
+	return;
+
+      saving = 1;
+      shutting_down = 0;
+      REMOVE (live_list, client);
+      g_assert (! save_yourself_request);
+      APPEND (save_yourself_list, client);
+      /* We ignore `shutdown' when a single-client save requested.  */
+      SmsSaveYourself (client->connection, save_type, 0, interact_style,
+		       fast);
     }
   else
     {
@@ -258,13 +278,31 @@ save_yourself_p2_request (SmsConn connection, SmPointer data)
   APPEND (save_yourself_p2_list, client);
 }
 
+/* A helper function.  Finds and executes each shutdown command.  */
+static void
+run_shutdown_commands (const GSList *list)
+{
+  for (; list; list = list->next)
+    {
+      Client *client = (Client *) list->data;
+      char **argv;
+      int argc;
+
+      if (find_vector_property (client, SmShutdownCommand, &argc, &argv))
+	{
+	  gnome_execute_async (NULL, argc, argv);
+	  free_vector (argc, argv);
+	}
+    }
+}
+
 /* This is a helper function which is run when it might be time to
    actually save the session.  It is run when the save_yourself lists
    are modified.  */
 static void
 check_session_end (int found)
 {
-  if (! live_list && ! interact_list && ! save_yourself_list)
+  if (! interact_list && ! save_yourself_list)
     {
       if (! save_yourself_p2_list)
 	{
@@ -276,12 +314,20 @@ check_session_end (int found)
 	  saving = 0;
 	  send_message (save_finished_list,
 			shutting_down ? SmsDie : SmsSaveComplete);
-	  live_list = save_finished_list;
+	  CONCAT (live_list, save_finished_list);
 	  save_finished_list = NULL;
 	  if (shutting_down)
 	    {
+	      /* Run each shutdown command.  The manual doesn't make
+		 it clear whether this should be done for all clients
+		 or only those that have RestartAnyway set.  We run
+		 them all.  */
+	      run_shutdown_commands (anyway_list);
+	      run_shutdown_commands (live_list);
+
 	      /* Make sure that all client connections are closed.  */
 	      send_message (live_list, kill_client_connection);
+
 	      gtk_main_quit ();
 	    }
 	}
