@@ -1,8 +1,10 @@
 /* This file should encapsulate all the HTML widget functionality. */
 /* No other files should be accessing HTML widget functions!       */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -569,8 +571,11 @@ helpWindowClose(HelpWindow win)
 
 static void init_accel(HelpWindow win)
 {
+#ifdef GTK_HAVE_FEATURES_1_1_0
+    GtkAccelGroup *accelGroup;
+#else
     GtkAcceleratorTable *accelTable;
-
+#endif
     /* What a hack this is.  I'm sure there is a better way */
     win->accelWidget = gtk_button_new_with_label("accelWidget");
     gtk_widget_realize(win->accelWidget);
@@ -582,18 +587,34 @@ static void init_accel(HelpWindow win)
 		       GTK_SIGNAL_FUNC(pageDown), win);
     gtk_signal_connect(GTK_OBJECT(win->accelWidget), "enter",
 		       GTK_SIGNAL_FUNC(focusEnter), win);
-    
+#ifdef GTK_HAVE_FEATURES_1_1_0
+    accelGroup = gtk_object_get_data(GTK_OBJECT(win->app),
+				     "GtkAccelGroup");
+    gtk_widget_add_accelerator(win->accelWidget,
+		    "pressed",
+		    accelGroup,
+		    'b', 0, 0);
+    gtk_widget_add_accelerator(win->accelWidget,
+		    "released",
+		    accelGroup,
+		    ' ', 0, 0);
+    gtk_widget_add_accelerator(win->accelWidget,
+		    "enter",
+		    accelGroup,
+		    'g', 0, 0);
+#else
     accelTable = gtk_object_get_data(GTK_OBJECT(win->app),
-				     "GtkAcceleratorTable");
+                                     "GtkAcceleratorTable");
     gtk_accelerator_table_install(accelTable,
-				  GTK_OBJECT(win->accelWidget), "pressed",
-				  'b', 0);
+                                  GTK_OBJECT(win->accelWidget), "pressed",
+                                  'b', 0);
     gtk_accelerator_table_install(accelTable,
-				  GTK_OBJECT(win->accelWidget), "released",
-				  ' ', 0);
+                                  GTK_OBJECT(win->accelWidget), "released",
+                                  ' ', 0);
     gtk_accelerator_table_install(accelTable,
-				  GTK_OBJECT(win->accelWidget), "enter",
-				  'g', 0);
+                                  GTK_OBJECT(win->accelWidget), "enter",
+                                  'g', 0);
+#endif
 }
 
 static void pageUp(GtkWidget *w, HelpWindow win)
@@ -822,6 +843,9 @@ GtkWidget
 
 
 /* HACK HACK HACK */
+/*
+ * Among problems this routine has - it leaves temp files in /tmp 
+ */
 XmImageInfo *
 load_image(GtkWidget *html_widget, gchar *ref)
 {
@@ -831,6 +855,7 @@ load_image(GtkWidget *html_widget, gchar *ref)
 	XmImageInfo *info;
 	gint buflen;
 	gint fd;
+	char tmpnam[]="/tmp/GnomeHelpBrowser-tmp.XXXXXX";
 
 	win = gtk_object_get_data(GTK_OBJECT(html_widget), "HelpWindow");
 	obj = docObjNew(ref, win->useCache);
@@ -847,7 +872,7 @@ load_image(GtkWidget *html_widget, gchar *ref)
 	    return NULL;
 	}
 	
-	fd = open(IMAGE_TEMPFILE, O_WRONLY | O_CREAT, 0666);
+	fd = mkstemp(tmpnam);
 	if (fd >= 0) {
 	    docObjGetRawData(obj, &buf, &buflen);
 	    write(fd, buf, buflen);
@@ -855,6 +880,5 @@ load_image(GtkWidget *html_widget, gchar *ref)
 	}
 		
 	docObjFree(obj);
-	return XmHTMLImageDefaultProc(html_widget, IMAGE_TEMPFILE,
-				      NULL, 0);
+	return XmHTMLImageDefaultProc(html_widget, tmpnam, NULL, 0);
 }
