@@ -5,23 +5,23 @@
 
 BEGIN_GNOME_DECLS
 
-#define DRAWER_PANEL "drawer_panel"
+#define DRAWER_PANEL_KEY "drawer_panel"
 
 typedef struct {
+	char *pixmap;
+	char *tooltip;
 	GtkWidget *button;
 	GtkWidget *drawer;
 	PanelOrientType orient;
 } Drawer;
 
-Drawer * create_drawer_applet(GtkWidget * drawer_panel,
-			      PanelOrientType orient);
+void load_drawer_applet(char *params, char *pixmap, char *tooltip,
+			int pos, PanelWidget *panel);
 
 void set_drawer_applet_orient(Drawer *drawer, PanelOrientType orient);
 
-Drawer * create_empty_drawer_applet(PanelOrientType orient);
-
 void reposition_drawer(Drawer *drawer);
-
+void drawer_properties(Drawer *drawer);
 
 END_GNOME_DECLS
 
