@@ -11,14 +11,23 @@
 #ifndef LAUNCHER_H
 #define LAUNCHER_H
 
+#include <panel-widget.h>
+
+BEGIN_GNOME_DECLS
+
 typedef struct {
 	int                applet_id;
 	GtkWidget         *button;
-	gint               signal_click_tag;
+	int                signal_click_tag;
+	GtkObject	  *dedit;
 	GnomeDesktopEntry *dentry;
 } Launcher;
 
-Launcher * create_launcher (char *parameters);
+void load_launcher_applet(char *params, int pos, PanelWidget *panel);
 void launcher_properties(Launcher *launcher);
 
+void ask_about_launcher(void);
+
+END_GNOME_DECLS
+
 #endif
