@@ -2,8 +2,10 @@
 /* Original author unknown. CORBAized by Elliot Lee */
 /* uncorbized by George Lebl */
 
+#include <config.h>
 #include <gnome.h>
-#include "panel.h"
+
+#include "panel-include.h"
 
 static void
 logout(void)
@@ -11,7 +13,7 @@ logout(void)
 	panel_quit();
 }
 
-GtkWidget *
+static GtkWidget *
 create_logout_widget(void)
 {
 	GtkWidget *button;
@@ -38,3 +40,15 @@ create_logout_widget(void)
 
 	return button;
 }
+
+void
+load_logout_applet(int pos, PanelWidget *panel)
+{
+	GtkWidget *logout;
+
+	logout = create_logout_widget();
+
+	if(logout)
+		register_toy(logout,NULL, pos, panel,APPLET_LOGOUT);
+}
+
