@@ -3,14 +3,21 @@
 #include <mico/gtkmico.h>
 #include <mico/naming.h>
 #include <gnome.h>
-#include "mico-glue.h"
+
+#include "panel-include.h"
 #include "gnome-panel.h"
-#include "panel.h"
-#include "panel-widget.h"
-#include "mico-parse.h"
 
 #include "cookie.h"
 
+extern char *panel_cfg_path;
+extern char *old_panel_cfg_path;
+
+extern int config_sync_timeout;
+extern GList *panels_to_sync;
+extern GList *applets_to_sync;
+extern int globals_to_sync;
+extern int need_complete_save;
+
 /* This implements the server-side of the gnome-panel.idl
  * specification Currently there is no way to create new CORBA
  * "instances" of the panel, as there is only one panel running on the
@@ -59,15 +66,8 @@ public:
 	}
 	void applet_request_glob_cfg (const char *ccookie,
 				      char *&globcfgpath) {
-		char *globcfg=NULL;
-
 		CHECK_COOKIE ();
-		::applet_request_glob_cfg (&globcfg);
-		if(globcfg) {
-			globcfgpath = CORBA::string_dup(globcfg);
-			g_free(globcfg);
-		} else
-			globcfgpath = CORBA::string_dup("");
+		globcfgpath = CORBA::string_dup(old_panel_cfg_path);
 	}
 	CORBA::Short applet_get_panel (const char *ccookie,
 				       CORBA::Short applet_id) {
@@ -82,7 +82,7 @@ public:
 	CORBA::Short applet_get_panel_orient (const char *ccookie,
 				              CORBA::Short applet_id) {
 		CHECK_COOKIE_V (0);
-		return (gint)::applet_get_panel_orient (applet_id);
+		return (int)::applet_get_panel_orient (applet_id);
 	}
 	void applet_show_menu (const char *ccookie, CORBA::Short applet_id) {
 		CHECK_COOKIE ();
@@ -99,15 +99,17 @@ public:
 	void applet_remove_from_panel (const char *ccookie,
 				       CORBA::Short applet_id) {
 		CHECK_COOKIE ();
-		::applet_remove_from_panel(applet_id);
+		::panel_clean_applet(applet_id);
 	}
         void applet_add_callback (const char *ccookie, 
 				  CORBA::Short applet_id,
 				  const char *callback_name,
+				  const char *stock_item,
 				  const char *menuitem_text) {
 		CHECK_COOKIE ();
 		::applet_add_callback(applet_id,
 				      (char *)callback_name,
+				      (char *)stock_item,
 				      (char *)menuitem_text);
 	}
         void applet_remove_callback (const char *ccookie, 
@@ -131,9 +133,13 @@ public:
 		CHECK_COOKIE_V (FALSE);
 		return panel_applet_in_drag;
 	}
-	void sync_config(const char *ccookie) {
+	void sync_config(const char *ccookie,
+			 CORBA::Short applet_id) {
 		CHECK_COOKIE ();
-		::panel_sync_config();
+		if(g_list_find(applets_to_sync,GINT_TO_POINTER(applet_id))==NULL)
+			applets_to_sync = g_list_prepend(applets_to_sync,
+							 GINT_TO_POINTER(applet_id));
+		panel_config_sync();
 	}
 	void quit(const char *ccookie) {
 		CHECK_COOKIE ();
@@ -166,8 +172,21 @@ panel_corba_gtk_main (char *service_name)
 	
 	orb_ptr->dispatcher (new GtkDispatcher ());
 	boa_ptr->impl_is_ready (CORBA::ImplementationDef::_nil());
+#ifdef HAVE_MICO_ORB_RUN	
+	orb_ptr->run ();
+#endif
 }
 
+void
+panel_corba_gtk_main_quit(void)
+{
+	boa_ptr->deactivate_impl (CORBA::ImplementationDef::_nil());
+#ifdef HAVE_MICO_ORB_RUN	
+	orb_ptr->shutdown (TRUE);
+#endif
+}
+
+
 void
 panel_corba_clean_up(void)
 {
@@ -249,3 +268,41 @@ send_applet_start_new_applet (const char *ior, const char *param)
 		g_warning(_("Error on sending 'start new applet' to applet!"));
 	}
 }
+
+void
+send_applet_change_back (const char *ior, int applet_id,
+			 PanelBackType back_type, const char *pixmap,
+			 const GdkColor* color)
+{
+	/* Use the ior that was sent to us to get an Applet CORBA object */
+	CORBA::Object_var obj = orb_ptr->string_to_object (ior);
+	GNOME::Applet_var applet = GNOME::Applet::_narrow (obj);
+
+	/* Now, use corba to invoke the routine in the panel */
+	try {
+		applet->back_change(cookie,applet_id, back_type, pixmap,
+				    color->red,color->green,color->blue);
+	} catch(...) {
+		g_warning(_("Error on sending 'change back' to applet!"));
+	}
+}
+
+void
+send_applet_tooltips_state (const char *ior, int enabled)
+{
+	/* Use the ior that was sent to us to get an Applet CORBA object */
+	CORBA::Object_var obj = orb_ptr->string_to_object (ior);
+	GNOME::Applet_var applet = GNOME::Applet::_narrow (obj);
+
+	/* Now, use corba to invoke the routine in the panel */
+	try {
+		applet->tooltips_state(cookie, enabled);
+	} catch(...) {
+		g_warning(_("Error on sending 'tooltips state' to applet!"));
+	}
+}
+
+void
+panel_corba_gtk_init (void)
+{
+}
