@@ -3,10 +3,8 @@
 #include <string.h>
 #include <config.h>
 #include <gnome.h>
-#include "panel.h"
-#include "panel-widget.h"
-#include "panel_config.h"
-#include "panel_config_global.h"
+
+#include "panel-include.h"
 
 /* Used for all the packing and padding options */
 #define CONFIG_PADDING_SIZE 3
@@ -17,6 +15,11 @@
 GlobalConfig temp_config;
 
 extern GlobalConfig global_config;
+extern int config_sync_timeout;
+extern int panels_to_sync;
+extern GList *applets_to_sync;
+extern int globals_to_sync;
+extern int need_complete_save;
 
 extern GList *panels;
 
@@ -25,7 +28,7 @@ static GtkWidget *aniframe[3];
 
 static GtkWidget *config_window;
 
-static gint
+static int
 config_destroy(GtkWidget *widget, gpointer data)
 {
 	config_window = NULL;
@@ -50,22 +53,23 @@ config_apply (GtkWidget *widget, int page, gpointer data)
 	memcpy(&global_config,&temp_config,sizeof(GlobalConfig));
 
 	apply_global_config();
-	
-	panel_sync_config();
+
+	globals_to_sync = TRUE;
+	panel_config_sync();
 }
 
 static void
-gint_scale_update (GtkAdjustment *adjustment, gpointer data)
+int_scale_update (GtkAdjustment *adjustment, gpointer data)
 {
-	gint *val = data;
+	int *val = data;
 	double scale_val = adjustment->value;
-	*val = (gint) scale_val;
+	*val = (int) scale_val;
 	if(config_window)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (config_window));
 }
 
 GtkWidget *
-make_gint_scale_frame(gchar *title, gint *data, double min, double max)
+make_int_scale_frame(char *title, int *data, double min, double max)
 {
 	GtkWidget *frame;
 	GtkWidget *box;
@@ -93,18 +97,18 @@ make_gint_scale_frame(gchar *title, gint *data, double min, double max)
 	gtk_box_pack_start (GTK_BOX (box), scale, TRUE, TRUE, CONFIG_PADDING_SIZE);
 	gtk_signal_connect(GTK_OBJECT (scale_data), 
 			   "value_changed",
-			   GTK_SIGNAL_FUNC (gint_scale_update),
+			   GTK_SIGNAL_FUNC (int_scale_update),
 			   data);
 	gtk_widget_show (scale);
 
 	return frame;
 }
 
-static gint
+static int
 set_anim_button_value(GtkWidget *w, gpointer data)
 {
-	gint i;
-	gint active = GTK_TOGGLE_BUTTON(w)->active;
+	int i;
+	int active = GTK_TOGGLE_BUTTON(w)->active;
 
 	for(i=0;i<3;i++)
 		gtk_widget_set_sensitive(aniframe[i],!active);
@@ -112,6 +116,7 @@ set_anim_button_value(GtkWidget *w, gpointer data)
 
 	if(config_window)
 		gnome_property_box_changed (GNOME_PROPERTY_BOX (config_window));
+	return FALSE;
 }
 
 GtkWidget *
@@ -134,7 +139,7 @@ animation_notebook_page(void)
 
 
 	/* AutoHide Animation step_size scale frame */
-	frame = make_gint_scale_frame(_("Auto-Hide Animation Speed"),
+	frame = make_int_scale_frame(_("Auto-Hide Animation Speed"),
 				      &(temp_config.auto_hide_step_size),
 				      1.0,100.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
@@ -143,7 +148,7 @@ animation_notebook_page(void)
 	aniframe[0] = frame;
 
 	/* ExplicitHide Animation step_size scale frame */
-	frame = make_gint_scale_frame(_("Explicit-Hide Animation Speed"),
+	frame = make_int_scale_frame(_("Explicit-Hide Animation Speed"),
 				      &(temp_config.explicit_hide_step_size),
 				      1.0,100.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
@@ -152,7 +157,7 @@ animation_notebook_page(void)
 	aniframe[1] = frame;
 
 	/* DrawerHide Animation step_size scale frame */
-	frame = make_gint_scale_frame(_("Drawer Animation Speed"),
+	frame = make_int_scale_frame(_("Drawer Animation Speed"),
 				      &(temp_config.drawer_step_size),
 				      1.0,100.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
@@ -161,14 +166,14 @@ animation_notebook_page(void)
 	aniframe[2] = frame;
 
 	/* Minimize Delay scale frame */
-	frame = make_gint_scale_frame(_("Auto-Hide Minimize Delay (ms)"),
+	frame = make_int_scale_frame(_("Auto-Hide Minimize Delay (ms)"),
 				      &(temp_config.minimize_delay),
 				      30.0,1000.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
 			    CONFIG_PADDING_SIZE);
 
 	/* Minimized size scale frame */
-	frame = make_gint_scale_frame(_("Auto-Hide Minimized Size (pixels)"),
+	frame = make_int_scale_frame(_("Auto-Hide Minimized Size (pixels)"),
 				      &(temp_config.minimized_size),
 				      1.0,10.0);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE,
@@ -181,7 +186,7 @@ animation_notebook_page(void)
 	return (vbox);
 }
 
-static gint
+static int
 set_movement (GtkWidget *widget, gpointer data)
 {
 	PanelMovementType move_type = (PanelMovementType) data;
@@ -210,7 +215,7 @@ misc_notebook_page(void)
 	gtk_container_border_width(GTK_CONTAINER (vbox), CONFIG_PADDING_SIZE);
 	
 	/* Tooltips frame */
-	frame = gtk_frame_new (_("Icon Tooltips"));
+	frame = gtk_frame_new (_("Tooltips"));
 	gtk_container_border_width(GTK_CONTAINER (frame), CONFIG_PADDING_SIZE);
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE,
 			    CONFIG_PADDING_SIZE);
@@ -314,6 +319,7 @@ panel_config_global(void)
 {
 	GtkWidget *page;
 	GtkWidget *box;
+	GtkWidget *prop_nbook;
 	
 	/* return if the window is already up. */
 	if (config_window)
@@ -323,6 +329,8 @@ panel_config_global(void)
 
 	/* main window */
 	box = gnome_property_box_new ();
+	/*gtk_window_position(GTK_WINDOW(box), GTK_WIN_POS_CENTER);*/
+	gtk_window_set_policy(GTK_WINDOW(box), FALSE, FALSE, TRUE);
 	gtk_signal_connect(GTK_OBJECT(box), "destroy",
 			   GTK_SIGNAL_FUNC (config_destroy), NULL);
 	gtk_signal_connect (GTK_OBJECT (box), "delete_event",
@@ -331,15 +339,17 @@ panel_config_global(void)
 			      _("Global Panel Configuration"));
 	gtk_container_border_width (GTK_CONTAINER(box), CONFIG_PADDING_SIZE);
 	
+	prop_nbook = GNOME_PROPERTY_BOX (box)->notebook;
+
 	/* Animation notebook page */
 	page = animation_notebook_page ();
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (box),
-					page, gtk_label_new (_("Animation settings")));
+	gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
+				  page, gtk_label_new (_("Animation settings")));
 
 	/* Miscellaneous notebook page */
 	page = misc_notebook_page ();
-	gnome_property_box_append_page (GNOME_PROPERTY_BOX (box),
-					page, gtk_label_new (_("Miscellaneous")));
+	gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
+				  page, gtk_label_new (_("Miscellaneous")));
 
 	gtk_signal_connect (GTK_OBJECT (box), "apply",
 			    GTK_SIGNAL_FUNC (config_apply), NULL);
